@@ -6,7 +6,9 @@ use Data::Recursive::Encode;
 use parent qw/Exporter/;
 our @EXPORT = qw/eDumper Dumper/;
 
-our $VERSION = '0.012';
+our $VERSION = '0.101';
+
+our $ENCODING = '';
 
 sub _dump {
     my $d = Data::Dumper->new(\@_);
@@ -14,11 +16,11 @@ sub _dump {
 }
 
 sub eDumper {
-    my ($ref, $enc) = @_;
-
-    _dump(
-        Data::Recursive::Encode->encode($enc || 'utf8', $ref)
-    );
+    my @args;
+    for my $arg (@_) {
+        push @args, Data::Recursive::Encode->encode($ENCODING || 'utf8', $arg);
+    }
+    _dump(@args);
 }
 
 1;
@@ -75,10 +77,14 @@ Also `Dumper` function is exported from Data::Dumper::AutoEncode. It is same as
 
 =over
 
-=item eDumper($dump_target_ref [, $encoding])
+=item eDumper(LIST)
 
 Dump with recursive encoding(default: utf8)
 
+If you want to encode other encoding, set encoding to $Data::Dumper::AutoEncode::ENCODING.
+
+    $Data::Dumper::AutoEncode::ENCODING = 'CP932';
+
 =item Dumper(LIST)
 
 same as Data::Dumper::Dumper
@@ -101,6 +107,13 @@ Dai Okabayashi E<lt>bayashi@cpan.orgE<gt>
 L<Data::Dumper>
 
 
+=head1 THANKS
+
+gfx
+
+tomyhero
+
+
 =head1 LICENSE
 
 This module is free software; you can redistribute it and/or
